@@ -57,8 +57,14 @@ class SettingAdmin(FlaskView):
             db.session.commit()
             from flask_babel import refresh; refresh()
             
-            do_full_install=old_config[ConfigEnum.telegram_lib]!=hconfig(ConfigEnum.telegram_lib)
-            hiddify.flash_config_success(full_install=do_full_install)
+            restart_mode=''
+            for c in old_config:
+                if old_config[c]!=hconfig(c) and c.apply_mode()!='':
+                    if restart_mode!='reinstall':
+                        restart_mode=c.apply_mode()
+            # do_full_install=old_config[ConfigEnum.telegram_lib]!=hconfig(ConfigEnum.telegram_lib)
+            if restart_mode!='':
+                hiddify.flash_config_success(full_install=restart_mode=='reinstall',domain_changed=False)
             
 
             return render_template('config.html', form=form)
